


<p align="center"><img src="https://raw.githubusercontent.com/sambe-consulting/sego/master/sego/assets/logo.png?token=ASI6IMQLECOW25335IBSGZLAJFVMW" width="400"></p>

<p align="center"><h3 style="color: #193967; text-align: center">A web and micro-service framework for data analysts </h3></p>

<p align="center">
<a href="https://github.com/sambe-consulting/sego/actions/workflows/pytest-workflow.yml"><img src="https://github.com/sambe-consulting/sego/actions/workflows/pytest-workflow.yml/badge.svg"></a>
<a href="https://houndci.com"><img src="https://img.shields.io/badge/Reviewed_by-Hound-8E64B0.svg"></a>
<a href="https://github.com/apache/zookeeper/blob/master/LICENSE.txt"><img src="https://img.shields.io/github/license/apache/zookeeper"></a>


</p>

## About Sego

Sego is a suite of tools for the "last mile" of ML and analytics projects. Sego is built to assist data scientists, analysts and engineers,productionize 
ML workloads with ease. Sego is primarily used for:
- Model serving 
- Multi-stage data processing
- Dashboards 
- Metrics and alerting 
- Database schema management 


Sego can also be used to build:
- Rest APIs 
- Micro-service topologies 
- Normal MVC webapps 

Sego provides an opinionated way to build production ML and analytics systems, but flexible enough to fit into different applications. It creates a 
rapid development environment. 

### Key Components
- Web Framework
- Micro-service framework
- Distributed tasks
- Native integration to <a href="https://github.com/sambe-consulting/confo">Confo </a> for all configuration management tasks,which also allows the building of complex topologies. 
#### Name etymology
Sego is a <a href="https://en.wikipedia.org/wiki/Northern_Sotho_language">Sepedi </a> word which refers to a flask made out of <a href="https://en.wikipedia.org/wiki/Calabash">Calabash gourd</a>, appropriately named as a nod to 
the elegantly built <a href="https://github.com/pallets/flask">Flask framework</a>


## Getting started

```
pip install sego
```


